-- RelicInspector.lua
-- Author: Thoralie

local addonName, addon = ...
local RelicSpells = addon.SpellIDByRelic

local RelicTypeNames = {
	[1] = RELIC_SLOT_TYPE_BLOOD,
	[2] = RELIC_SLOT_TYPE_SHADOW,
	[3] = RELIC_SLOT_TYPE_IRON,
	[4] = RELIC_SLOT_TYPE_FROST,
	[5] = RELIC_SLOT_TYPE_FIRE,
	[6] = RELIC_SLOT_TYPE_FEL,
	[7] = RELIC_SLOT_TYPE_ARCANE,
	[8] = RELIC_SLOT_TYPE_LIFE,
	[9] = RELIC_SLOT_TYPE_WIND,
	[10] = RELIC_SLOT_TYPE_HOLY,
}

local RelicSlotsByArtifact = {
	[127829] = { 6, 2, 6}, -- Havoc DH
	[128832] = { 3, 7, 6}, -- Vengeance DH

	[128402] = { 1, 2, 3}, -- Blood DK
	[128292] = { 4, 2, 4}, -- Frost DK
	[128403] = { 5, 2, 1}, -- Unholy DK

	[128858] = { 7, 8, 7}, -- Balance Druid
	[128860] = { 4, 1, 8}, -- Feral Druid
	[128821] = { 5, 1, 8}, -- Guardian Druid
	[128306] = { 8, 4, 8}, -- Restoration Druid

	[128861] = { 9, 7, 3}, -- Beast Mastery Hunter
	[128826] = { 9, 1, 8}, -- Marksmanship Hunter
	[128808] = { 9, 3, 1}, -- Survival Hunter

	[127857] = { 7, 4, 7}, -- Arcane Mage
	[128820] = { 5, 7, 5}, -- Fire Mage
	[128862] = { 4, 7, 4}, -- Frost Mage

	[128938] = { 8, 9, 3}, -- Brewmaster Monk
	[128937] = { 4, 8, 9}, -- Mistweaver Monk
	[128940] = { 9, 3, 9}, -- Windwalker Monk

	[128823] = { 10, 8, 10}, -- Holy Paladin
	[128866] = { 10, 3, 7}, -- Protection Paladin
	[120978] = { 10, 5, 10}, -- Retribution Paladin

	[128868] = { 10, 2, 10}, -- Discipline Priest
	[128825] = { 10, 8, 10}, -- Holy Priest
	[128827] = { 2, 1, 2}, -- Shadow Priest

	[128870] = { 2, 3, 1}, -- Assassination Rogue
	[128872] = { 1, 3, 9}, -- Outlaw Rogue
	[128476] = { 6, 2, 6}, -- Subtlety Rogue

	[128935] = { 9, 4, 9}, -- Elemental Shaman
	[128819] = { 5, 3, 9}, -- Enhancement Shaman
	[128911] = { 8, 4, 8}, -- Restoration Shaman

	[128942] = { 2, 1, 2}, -- Affliction Warlock
	[128943] = { 2, 5, 6}, -- Demonology Warlock
	[128941] = { 6, 5, 6}, -- Destruction Warlock

	[128910] = { 3, 1, 2}, -- Arms Warrior
	[128908] = { 5, 9, 3}, -- Fury Warrior
	[128289] = { 3, 1, 5}, -- Protection Warrior
}

local fullTextModifierPressed = 0

local DEBUG = 0

local function DecorateTooltip(self)
	local _, link = self:GetItem()
	if type(link) == 'string' then
		local _, itemID, _, relic1, relic2, relic3, _, _, _, _, _, upgradeID = strsplit(':', link)
		if upgradeID == '256' and nil ~= RelicSlotsByArtifact[tonumber(itemID)] then
			local relics = {relic1,relic2,relic3}
			for i = 1,3 do 
				if '' ~= relics[i] then
					if DEBUG == 1 then print(format("Found Relic %d",i)) end

					local name, gemLink = GetItemGem(link,i)
					if type(gemLink) == 'string' then
						if DEBUG == 1 then print(format("Gem Link: %s",gemLink)) end
						--Display the gem name, item level, and relic type
						local _, _, _, gemLevel = GetItemInfo(gemLink)
						local relicType = RelicTypeNames[RelicSlotsByArtifact[tonumber(itemID)][i]]

						if nil == relicType then
							relicType = "???"
						end
						self:AddDoubleLine(format('|cffffd400 (%s) %s|r', gemLevel or '???', gemLink or '???'), 
							format('|cff00ff00(%s)',relicType), 0, 1, 0, 0, 1, 0)

						-- Let's add the Ranks and Trait names if we have them
						local spellLookupKey = itemID .. '.' .. relics[i]
						local traitSpellID = RelicSpells[spellLookupKey]
						if DEBUG == 1 then print(format("Trait Spell ID: %d",traitSpellID)) end

						if nil ~= traitSpellID then
							local traitName = GetSpellInfo(traitSpellID)
							if DEBUG == 1 then print(format("Trait Name: %s",traitName)) end

							if nil ~= traitName then
								-- Assuming 1 Rank per relic right now. Will have to update this if relics start giving more than 1 rank
								self:AddLine(format(' ' .. RELIC_TOOLTIP_RANK_INCREASE, 1, traitName), 0, 1, 0, false)

								-- Full Text if Control key is held down or if it's a ItemRefTooltip (linked) tooltip
								if fullTextModifierPressed ~= 0 or self:GetName() == "ItemRefTooltip" then
									local traitDesc = GetSpellDescription(traitSpellID)
									if nil ~= traitDesc then
										self:AddLine(format('|cffff78ff  %s|r', traitDesc), 1, 1, 0, true)
									end
								end
							end
						end
					end	
				end
			end
		end 
	end
end

GameTooltip:RegisterEvent("MODIFIER_STATE_CHANGED")
GameTooltip:HookScript("OnEvent", function(self, event, key, state)
	if event == "MODIFIER_STATE_CHANGED" and (key == "LCTRL" or key == "RCTRL") then
		fullTextModifierPressed = state
	end
end)

ItemRefTooltip:HookScript('OnTooltipSetItem', DecorateTooltip)
GameTooltip:HookScript('OnTooltipSetItem', DecorateTooltip)
ShoppingTooltip1:HookScript('OnTooltipSetItem', DecorateTooltip)
ShoppingTooltip2:HookScript('OnTooltipSetItem', DecorateTooltip)

